@@ -10,4 +10,7 @@
         if(!require(stats))                 
             warning("Could not load package stats")      
     }
+
+    cat("  Package", sQuote("exactRankTests"), "is no longer under development.\n",
+        " Please consider using package", sQuote("coin"), "instead.\n")
 }
